package passe

  1. Overview
  2. Docs

Changes

0.1.0

Initial release of passe, includes:

  • Bcrypt hash and verify functions
  • Argon2 hash and verify functions

0.2.0

  • Fix int literal constant is too large for 32-bit systems #10
  • Add exn functions that raise exceptions instead of returning results #11