package passe
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Module Passe.Argon2Source
type error = [ | `Invalid_time_cost of string| `Invalid_memory_cost of string| `Invalid_parallelism of string| `Invalid_salt_length of int| `Hash_failure of string| `Verify_mismatch| `Invalid_hash of string
]pp_error fmt err pretty print bcrypt error err to formatter fmt
hash_with_salt ~salt ~params password hash the password using the given salt and params
hash ?params password hash the password using the given params. If no params is provided, default params are used.