package passe
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Module Passe.BcryptSource
type error = [ | `Hash_failure| `Invalid_cost of string| `Invalid_hash of string| `Invalid_prefix of string| `Invalid_salt_length of int| `Salt_generation_failure| `Truncated of int
]pp_error fmt err pretty print bcrypt error err to formatter fmt
hash_with_salt ~salt password hash the password using the given salt
hash ?cost password hash the password using the given cost. If no cost is provided, a default cost of 12 is used.